@@ -165,6 +165,18 @@ def get_global_share_tag_options_default(puppet_account_id, default_region=None)
     )
 
 
+@functools.lru_cache(maxsize=32)
+def get_global_share_principals_default(puppet_account_id, default_region=None):
+    logger.info(
+        "getting global_share_principals_default,  default_region: {}".format(
+            default_region
+        )
+    )
+    return get_config(puppet_account_id, default_region).get(
+        "global_share_principals_default", constants.SHARE_PRINCIPALS_DEFAULT
+    )
+
+
 def get_spoke_deploy_environment_compute_type(puppet_account_id, default_region):
     logger.info(
         "getting spoke_deploy_environment_compute_type,  default_region: {}".format(
